@@ -1,4 +1,5 @@
-int main(){
+int main()
+{
     printf("Hello World.\n");
     return 0;
 }
